Class: Aws::PartnerCentralBenefits::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PartnerCentralBenefits::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-partnercentralbenefits/client.rb,
sig/client.rbs
Overview
An API client for PartnerCentralBenefits. To construct a client, you need to configure a :region and :credentials.
client = Aws::PartnerCentralBenefits::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AmendBenefitApplicationResponseSuccess, _AssociateBenefitApplicationResourceResponseSuccess, _CancelBenefitApplicationResponseSuccess, _CreateBenefitApplicationResponseSuccess, _DisassociateBenefitApplicationResourceResponseSuccess, _GetBenefitAllocationResponseSuccess, _GetBenefitApplicationResponseSuccess, _GetBenefitResponseSuccess, _ListBenefitAllocationsResponseSuccess, _ListBenefitApplicationsResponseSuccess, _ListBenefitsResponseSuccess, _ListTagsForResourceResponseSuccess, _RecallBenefitApplicationResponseSuccess, _SubmitBenefitApplicationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateBenefitApplicationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#amend_benefit_application(params = {}) ⇒ Struct
Modifies an existing benefit application by applying amendments to specific fields while maintaining revision control.
-
#associate_benefit_application_resource(params = {}) ⇒ Types::AssociateBenefitApplicationResourceOutput
Links an AWS resource to an existing benefit application for tracking and management purposes.
-
#cancel_benefit_application(params = {}) ⇒ Struct
Cancels a benefit application that is currently in progress, preventing further processing.
-
#create_benefit_application(params = {}) ⇒ Types::CreateBenefitApplicationOutput
Creates a new benefit application for a partner to request access to AWS benefits and programs.
-
#disassociate_benefit_application_resource(params = {}) ⇒ Types::DisassociateBenefitApplicationResourceOutput
Removes the association between an AWS resource and a benefit application.
-
#get_benefit(params = {}) ⇒ Types::GetBenefitOutput
Retrieves detailed information about a specific benefit available in the partner catalog.
-
#get_benefit_allocation(params = {}) ⇒ Types::GetBenefitAllocationOutput
Retrieves detailed information about a specific benefit allocation that has been granted to a partner.
-
#get_benefit_application(params = {}) ⇒ Types::GetBenefitApplicationOutput
Retrieves detailed information about a specific benefit application.
-
#list_benefit_allocations(params = {}) ⇒ Types::ListBenefitAllocationsOutput
Retrieves a paginated list of benefit allocations based on specified filter criteria.
-
#list_benefit_applications(params = {}) ⇒ Types::ListBenefitApplicationsOutput
Retrieves a paginated list of benefit applications based on specified filter criteria.
-
#list_benefits(params = {}) ⇒ Types::ListBenefitsOutput
Retrieves a paginated list of available benefits based on specified filter criteria.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves all tags associated with a specific resource.
-
#recall_benefit_application(params = {}) ⇒ Struct
Recalls a submitted benefit application, returning it to draft status for further modifications.
-
#submit_benefit_application(params = {}) ⇒ Struct
Submits a benefit application for review and processing by AWS.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes specified tags from a resource.
-
#update_benefit_application(params = {}) ⇒ Types::UpdateBenefitApplicationOutput
Updates an existing benefit application with new information while maintaining revision control.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1500 1501 1502 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1500 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1503 1504 1505 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1503 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#amend_benefit_application(params = {}) ⇒ Struct
Modifies an existing benefit application by applying amendments to specific fields while maintaining revision control.
86 |
# File 'sig/client.rbs', line 86
def amend_benefit_application: (
|
#associate_benefit_application_resource(params = {}) ⇒ Types::AssociateBenefitApplicationResourceOutput
Links an AWS resource to an existing benefit application for tracking and management purposes.
108 |
# File 'sig/client.rbs', line 108
def associate_benefit_application_resource: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1473 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PartnerCentralBenefits') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-partnercentralbenefits' context[:gem_version] = '1.9.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_benefit_application(params = {}) ⇒ Struct
Cancels a benefit application that is currently in progress, preventing further processing.
119 |
# File 'sig/client.rbs', line 119
def cancel_benefit_application: (
|
#create_benefit_application(params = {}) ⇒ Types::CreateBenefitApplicationOutput
Creates a new benefit application for a partner to request access to AWS benefits and programs.
134 |
# File 'sig/client.rbs', line 134
def create_benefit_application: (
|
#disassociate_benefit_application_resource(params = {}) ⇒ Types::DisassociateBenefitApplicationResourceOutput
Removes the association between an AWS resource and a benefit application.
175 |
# File 'sig/client.rbs', line 175
def disassociate_benefit_application_resource: (
|
#get_benefit(params = {}) ⇒ Types::GetBenefitOutput
Retrieves detailed information about a specific benefit available in the partner catalog.
195 |
# File 'sig/client.rbs', line 195
def get_benefit: (
|
#get_benefit_allocation(params = {}) ⇒ Types::GetBenefitAllocationOutput
Retrieves detailed information about a specific benefit allocation that has been granted to a partner.
221 |
# File 'sig/client.rbs', line 221
def get_benefit_allocation: (
|
#get_benefit_application(params = {}) ⇒ Types::GetBenefitApplicationOutput
Retrieves detailed information about a specific benefit application.
251 |
# File 'sig/client.rbs', line 251
def get_benefit_application: (
|
#list_benefit_allocations(params = {}) ⇒ Types::ListBenefitAllocationsOutput
Retrieves a paginated list of benefit allocations based on specified filter criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
263 |
# File 'sig/client.rbs', line 263
def list_benefit_allocations: (
|
#list_benefit_applications(params = {}) ⇒ Types::ListBenefitApplicationsOutput
Retrieves a paginated list of benefit applications based on specified filter criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
280 |
# File 'sig/client.rbs', line 280
def list_benefit_applications: (
|
#list_benefits(params = {}) ⇒ Types::ListBenefitsOutput
Retrieves a paginated list of available benefits based on specified filter criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
306 |
# File 'sig/client.rbs', line 306
def list_benefits: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves all tags associated with a specific resource.
321 |
# File 'sig/client.rbs', line 321
def list_tags_for_resource: (
|
#recall_benefit_application(params = {}) ⇒ Struct
Recalls a submitted benefit application, returning it to draft status for further modifications.
330 |
# File 'sig/client.rbs', line 330
def recall_benefit_application: (
|
#submit_benefit_application(params = {}) ⇒ Struct
Submits a benefit application for review and processing by AWS.
342 |
# File 'sig/client.rbs', line 342
def submit_benefit_application: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a specified resource.
352 |
# File 'sig/client.rbs', line 352
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes specified tags from a resource.
367 |
# File 'sig/client.rbs', line 367
def untag_resource: (
|
#update_benefit_application(params = {}) ⇒ Types::UpdateBenefitApplicationOutput
Updates an existing benefit application with new information while maintaining revision control.
380 |
# File 'sig/client.rbs', line 380
def update_benefit_application: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1493 1494 1495 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1493 def waiter_names [] end |