Class: Aws::PartnerCentralBenefits::Types::Amendment
- Inherits:
-
Struct
- Object
- Struct
- Aws::PartnerCentralBenefits::Types::Amendment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-partnercentralbenefits/types.rb
Overview
Represents a specific change to be made to a benefit application field.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_path ⇒ String
The JSON path or field identifier specifying which field in the benefit application to modify.
-
#new_value ⇒ String
The new value to set for the specified field in the benefit application.