Class: Aws::PartnerCentralBenefits::Types::DisassociateBenefitApplicationResourceOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-partnercentralbenefits/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the benefit application after the resource disassociation.

Returns:

  • (String)


712
713
714
715
716
717
718
# File 'lib/aws-sdk-partnercentralbenefits/types.rb', line 712

class DisassociateBenefitApplicationResourceOutput < Struct.new(
  :id,
  :arn,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the benefit application after the resource disassociation.

Returns:

  • (String)


712
713
714
715
716
717
718
# File 'lib/aws-sdk-partnercentralbenefits/types.rb', line 712

class DisassociateBenefitApplicationResourceOutput < Struct.new(
  :id,
  :arn,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end

#revisionString

The updated revision number of the benefit application after the resource disassociation.

Returns:

  • (String)


712
713
714
715
716
717
718
# File 'lib/aws-sdk-partnercentralbenefits/types.rb', line 712

class DisassociateBenefitApplicationResourceOutput < Struct.new(
  :id,
  :arn,
  :revision)
  SENSITIVE = []
  include Aws::Structure
end