Class: Aws::PartnerCentralBenefits::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PartnerCentralBenefits::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-partnercentralbenefits/client.rb
Overview
An API client for PartnerCentralBenefits. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::PartnerCentralBenefits::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#amend_benefit_application(params = {}) ⇒ Struct
Modifies an existing benefit application by applying amendments to specific fields while maintaining revision control.
-
#associate_benefit_application_resource(params = {}) ⇒ Types::AssociateBenefitApplicationResourceOutput
Links an AWS resource to an existing benefit application for tracking and management purposes.
-
#cancel_benefit_application(params = {}) ⇒ Struct
Cancels a benefit application that is currently in progress, preventing further processing.
-
#create_benefit_application(params = {}) ⇒ Types::CreateBenefitApplicationOutput
Creates a new benefit application for a partner to request access to AWS benefits and programs.
-
#disassociate_benefit_application_resource(params = {}) ⇒ Types::DisassociateBenefitApplicationResourceOutput
Removes the association between an AWS resource and a benefit application.
-
#get_benefit(params = {}) ⇒ Types::GetBenefitOutput
Retrieves detailed information about a specific benefit available in the partner catalog.
-
#get_benefit_allocation(params = {}) ⇒ Types::GetBenefitAllocationOutput
Retrieves detailed information about a specific benefit allocation that has been granted to a partner.
-
#get_benefit_application(params = {}) ⇒ Types::GetBenefitApplicationOutput
Retrieves detailed information about a specific benefit application.
-
#list_benefit_allocations(params = {}) ⇒ Types::ListBenefitAllocationsOutput
Retrieves a paginated list of benefit allocations based on specified filter criteria.
-
#list_benefit_applications(params = {}) ⇒ Types::ListBenefitApplicationsOutput
Retrieves a paginated list of benefit applications based on specified filter criteria.
-
#list_benefits(params = {}) ⇒ Types::ListBenefitsOutput
Retrieves a paginated list of available benefits based on specified filter criteria.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves all tags associated with a specific resource.
-
#recall_benefit_application(params = {}) ⇒ Struct
Recalls a submitted benefit application, returning it to draft status for further modifications.
-
#submit_benefit_application(params = {}) ⇒ Struct
Submits a benefit application for review and processing by AWS.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes specified tags from a resource.
-
#update_benefit_application(params = {}) ⇒ Types::UpdateBenefitApplicationOutput
Updates an existing benefit application with new information while maintaining revision control.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1500 1501 1502 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1500 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1503 1504 1505 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1503 def errors_module Errors end |
Instance Method Details
#amend_benefit_application(params = {}) ⇒ Struct
Modifies an existing benefit application by applying amendments to specific fields while maintaining revision control.
532 533 534 535 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 532 def amend_benefit_application(params = {}, = {}) req = build_request(:amend_benefit_application, params) req.send_request() end |
#associate_benefit_application_resource(params = {}) ⇒ Types::AssociateBenefitApplicationResourceOutput
Links an AWS resource to an existing benefit application for tracking and management purposes.
576 577 578 579 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 576 def associate_benefit_application_resource(params = {}, = {}) req = build_request(:associate_benefit_application_resource, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1473 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PartnerCentralBenefits') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-partnercentralbenefits' context[:gem_version] = '1.7.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_benefit_application(params = {}) ⇒ Struct
Cancels a benefit application that is currently in progress, preventing further processing.
614 615 616 617 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 614 def cancel_benefit_application(params = {}, = {}) req = build_request(:cancel_benefit_application, params) req.send_request() end |
#create_benefit_application(params = {}) ⇒ Types::CreateBenefitApplicationOutput
Creates a new benefit application for a partner to request access to AWS benefits and programs.
718 719 720 721 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 718 def create_benefit_application(params = {}, = {}) req = build_request(:create_benefit_application, params) req.send_request() end |
#disassociate_benefit_application_resource(params = {}) ⇒ Types::DisassociateBenefitApplicationResourceOutput
Removes the association between an AWS resource and a benefit application.
762 763 764 765 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 762 def disassociate_benefit_application_resource(params = {}, = {}) req = build_request(:disassociate_benefit_application_resource, params) req.send_request() end |
#get_benefit(params = {}) ⇒ Types::GetBenefitOutput
Retrieves detailed information about a specific benefit available in the partner catalog.
812 813 814 815 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 812 def get_benefit(params = {}, = {}) req = build_request(:get_benefit, params) req.send_request() end |
#get_benefit_allocation(params = {}) ⇒ Types::GetBenefitAllocationOutput
Retrieves detailed information about a specific benefit allocation that has been granted to a partner.
904 905 906 907 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 904 def get_benefit_allocation(params = {}, = {}) req = build_request(:get_benefit_allocation, params) req.send_request() end |
#get_benefit_application(params = {}) ⇒ Types::GetBenefitApplicationOutput
Retrieves detailed information about a specific benefit application.
990 991 992 993 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 990 def get_benefit_application(params = {}, = {}) req = build_request(:get_benefit_application, params) req.send_request() end |
#list_benefit_allocations(params = {}) ⇒ Types::ListBenefitAllocationsOutput
Retrieves a paginated list of benefit allocations based on specified filter criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1064 1065 1066 1067 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1064 def list_benefit_allocations(params = {}, = {}) req = build_request(:list_benefit_allocations, params) req.send_request() end |
#list_benefit_applications(params = {}) ⇒ Types::ListBenefitApplicationsOutput
Retrieves a paginated list of benefit applications based on specified filter criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1158 1159 1160 1161 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1158 def list_benefit_applications(params = {}, = {}) req = build_request(:list_benefit_applications, params) req.send_request() end |
#list_benefits(params = {}) ⇒ Types::ListBenefitsOutput
Retrieves a paginated list of available benefits based on specified filter criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1222 1223 1224 1225 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1222 def list_benefits(params = {}, = {}) req = build_request(:list_benefits, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves all tags associated with a specific resource.
1252 1253 1254 1255 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1252 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#recall_benefit_application(params = {}) ⇒ Struct
Recalls a submitted benefit application, returning it to draft status for further modifications.
1290 1291 1292 1293 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1290 def recall_benefit_application(params = {}, = {}) req = build_request(:recall_benefit_application, params) req.send_request() end |
#submit_benefit_application(params = {}) ⇒ Struct
Submits a benefit application for review and processing by AWS.
1317 1318 1319 1320 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1317 def submit_benefit_application(params = {}, = {}) req = build_request(:submit_benefit_application, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a specified resource.
1348 1349 1350 1351 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1348 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes specified tags from a resource.
1374 1375 1376 1377 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1374 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_benefit_application(params = {}) ⇒ Types::UpdateBenefitApplicationOutput
Updates an existing benefit application with new information while maintaining revision control.
1464 1465 1466 1467 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1464 def update_benefit_application(params = {}, = {}) req = build_request(:update_benefit_application, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1493 1494 1495 |
# File 'lib/aws-sdk-partnercentralbenefits/client.rb', line 1493 def waiter_names [] end |